diff src/org/tmatesoft/hg/repo/HgManifest.java @ 583:47dfa0ec7e35

Effective revlog patching
author Artem Tikhomirov <tikhomirov.artem@gmail.com>
date Wed, 24 Apr 2013 15:39:53 +0200
parents 88afffd39899
children c895b5556937 2f1cd1c26de5
line wrap: on
line diff
--- a/src/org/tmatesoft/hg/repo/HgManifest.java	Mon Apr 22 19:17:29 2013 +0200
+++ b/src/org/tmatesoft/hg/repo/HgManifest.java	Wed Apr 24 15:39:53 2013 +0200
@@ -371,12 +371,12 @@
 		 * Denotes entering specific manifest revision, separate entries are
 		 * reported with subsequence {@link #next(Nodeid, Path, Flags)} calls.
 		 * 
 		 * @param mainfestRevisionIndex  local revision index of the inspected revision
 		 * @param manifestRevision revision of the manifest we're about to iterate through
 		 * @param changelogRevisionIndex local revision index of changelog this manifest points to 
 		 * @return <code>true</code> to continue iteration, <code>false</code> to stop
 		 */
-		boolean begin(int mainfestRevisionIndex, Nodeid manifestRevision, int changelogRevisionIndex);
+		boolean begin(int manifestRevisionIndex, Nodeid manifestRevision, int changelogRevisionIndex);
 
 		
 		/**
@@ -371,12 +371,12 @@
 		 * reported with subsequence {@link #next(Nodeid, Path, Flags)} calls.
 		 * 
-		 * @param mainfestRevisionIndex  local revision index of the inspected revision
+		 * @param manifestRevisionIndex  local revision index of the inspected revision
 		 * @param manifestRevision revision of the manifest we're about to iterate through
 		 * @param changelogRevisionIndex local revision index of changelog this manifest points to 